MessageBus

Struct MessageBus 

pub struct MessageBus { /* private fields */ }
Async message bus that decouples chat channels from the agent core

Channels push messages to the inbound queue, and the agent processes them and pushes responses to the outbound queue.

Implementations

Source

impl MessageBus

pub fn new() -> Self

Create a new message bus

pub fn publish_event( &self, channel: impl Into<String>, chat_id: impl Into<String>, event: AgentEvent, ) -> Result<()>

Publish an event to the broadcast channel

pub fn subscribe_events(&self) -> Receiver<AgentBusEvent>

Subscribe to the event broadcast channel

pub async fn take_inbound_receiver( &self, ) -> Option<UnboundedReceiver<InboundMessage>>

Take the inbound receiver (can only be called once)

pub async fn take_outbound_receiver( &self, ) -> Option<UnboundedReceiver<OutboundMessage>>

Take the outbound receiver (can only be called once)

pub fn publish_inbound(&self, msg: InboundMessage) -> Result<()>

Publish a message from a channel to the agent

pub fn publish_outbound(&self, msg: OutboundMessage) -> Result<()>

Publish a response from the agent to channels

pub async fn subscribe_outbound<F, Fut>( &self, channel: impl Into<String>, callback: F, )
where F: Fn(OutboundMessage) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Subscribe to outbound messages for a specific channel with a callback

pub async fn dispatch_outbound_loop(&self)

Dispatch outbound messages to subscribed channels Run this as a background task

pub async fn stop(&self)

Stop the dispatcher loop

pub async fn is_running(&self) -> bool

Check if the bus is running