pub struct ConfigLoader { /* private fields */ }Expand description
Configuration loader
Implementations
Sourceimpl ConfigLoader
impl ConfigLoader
Sourcepub fn with_dir<P: AsRef<Path>>(dir: P) -> Self
pub fn with_dir<P: AsRef<Path>>(dir: P) -> Self
Create a new config loader with a custom config directory
Sourcepub fn with_file<P: AsRef<Path>>(path: P) -> Self
pub fn with_file<P: AsRef<Path>>(path: P) -> Self
Create a new config loader with an explicit config file path
Sourcepub fn config_dir(&self) -> &Path
pub fn config_dir(&self) -> &Path
Get the config directory path
Sourcepub fn config_path(&self) -> &Path
pub fn config_path(&self) -> &Path
Get the config file path