pub struct DiscordConfig {
pub enabled: bool,
pub token: String,
pub allow_from: Vec<String>,
pub gateway_url: String,
pub intents: u64,
pub guild_id: Option<String>,
pub mention_only: bool,
pub listen_to_bots: bool,
pub group_reply_allowed_sender_ids: Vec<String>,
}Expand description
Discord channel configuration
Fields
enabled: booltoken: Stringallow_from: Vec<String>gateway_url: Stringintents: u64guild_id: Option<String>When set, only guild messages from this server are handled (DMs are still allowed).
mention_only: boolIn guild channels, require @mention of the bot (unless sender is in group_reply_allowed_sender_ids).
listen_to_bots: boolWhen true, process messages from other bots.
group_reply_allowed_sender_ids: Vec<String>User IDs that may trigger the bot in guild channels without @mention when mention_only is true.