pub struct ActionTracker { /* private fields */ }Expand description
Tracks actions in a sliding window for rate limiting
Implementations
Sourceimpl ActionTracker
impl ActionTracker
Sourcepub fn with_window(window_secs: u64) -> Self
pub fn with_window(window_secs: u64) -> Self
Create a new action tracker with custom window size
Sourcepub fn is_rate_limited(&self, max_actions: u32) -> bool
pub fn is_rate_limited(&self, max_actions: u32) -> bool
Check if the action count exceeds the limit
Sourcepub fn try_record(&self, max_actions: u32) -> bool
pub fn try_record(&self, max_actions: u32) -> bool
Try to record an action, returning false if rate limited
Sourcepub fn window_duration(&self) -> Duration
pub fn window_duration(&self) -> Duration
Get the window duration